==> webkit2gtk_2.48.1.orig.tar.xz: webkitgtk-2.48.1/Source/WebCore/platform/graphics/NullImageBufferBackend.cpp <==
/*
 * Copyright (C) 2020-2021 Apple Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "NullImageBufferBackend.h"

#include "PixelBuffer.h"
#include <wtf/text/TextStream.h>
#include <wtf/text/WTFString.h>

namespace WebCore {

std::unique_ptr<NullImageBufferBackend> NullImageBufferBackend::create(const Parameters& parameters, const ImageBufferCreationContext&)
{
    return std::unique_ptr<NullImageBufferBackend> { new NullImageBufferBackend { parameters } };
}

NullImageBufferBackend::~NullImageBufferBackend() = default;

NullGraphicsContext& NullImageBufferBackend::context()
{
    return m_context;
}

RefPtr<NativeImage> NullImageBufferBackend::copyNativeImage()
{
    return nullptr;
}

RefPtr<NativeImage> NullImageBufferBackend::createNativeImageReference()
{
    return nullptr;
}

void NullImageBufferBackend::getPixelBuffer(const IntRect&, PixelBuffer& destination)
{
    destination.zeroFill();
}

void NullImageBufferBackend::putPixelBuffer(const PixelBuffer&, const IntRect&, const IntPoint&, AlphaPremultiplication)
{
}

unsigned NullImageBufferBackend::bytesPerRow() const
{
    return 0;
}

bool NullImageBufferBackend::canMapBackingStore() const
{
    return false;
}

String NullImageBufferBackend::debugDescription() const
{
    TextStream stream;
    stream << "NullImageBufferBackend " << this;
    return stream.release();
}

}

==> webkit2gtk_2.50.1.orig.tar.xz: webkitgtk-2.50.1/Source/WebCore/platform/graphics/NullImageBufferBackend.cpp <==
/*
 * Copyright (C) 2020-2021 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "NullImageBufferBackend.h"

#include "NativeImage.h"
#include "PixelBuffer.h"
#include <wtf/text/TextStream.h>
#include <wtf/text/WTFString.h>

namespace WebCore {

std::unique_ptr<NullImageBufferBackend> NullImageBufferBackend::create(const Parameters& parameters, const ImageBufferCreationContext&)
{
    return std::unique_ptr<NullImageBufferBackend> { new NullImageBufferBackend { parameters } };
}

NullImageBufferBackend::~NullImageBufferBackend() = default;

NullGraphicsContext& NullImageBufferBackend::context()
{
    return m_context;
}

RefPtr<NativeImage> NullImageBufferBackend::copyNativeImage()
{
    return nullptr;
}

RefPtr<NativeImage> NullImageBufferBackend::createNativeImageReference()
{
    return nullptr;
}

void NullImageBufferBackend::getPixelBuffer(const IntRect&, PixelBuffer& destination)
{
    destination.zeroFill();
}

void NullImageBufferBackend::putPixelBuffer(const PixelBufferSourceView&, const IntRect&, const IntPoint&, AlphaPremultiplication)
{
}

unsigned NullImageBufferBackend::bytesPerRow() const
{
    return 0;
}

bool NullImageBufferBackend::canMapBackingStore() const
{
    return false;
}

String NullImageBufferBackend::debugDescription() const
{
    TextStream stream;
    stream << "NullImageBufferBackend " << this;
    return stream.release();
}

}
